def camel_case_to_underscope(camel_case_string:str, leading_lower_is_private:bool=False, process_acronyms=True) -> str:
    
    result = ''
    i = 0
    if (i < len(camel_case_string)):
        s = camel_case_string[i]
        if (leading_lower_is_private):
            if (s != s.upper()):
                s = '_' + s.lower()
            else:
                s = s.lower()
        else:
            s = s.lower()

        result += s
        i += 1

    while (i < len(camel_case_string)):
        s = camel_case_string[i]
        if (s != s.lower()):
            if (process_acronyms
                and (i < 1 or camel_case_string[i-1] != camel_case_string[i-1].lower())
                and (i + 1 >= len(camel_case_string) or camel_case_string[i+1] != camel_case_string[i+1].lower())):
                s = s.lower()
            else:
                s = '_' + s.lower()

        result += s
        i += 1

    return result
CamelCaseToUnderscope = camel_case_to_underscope
camelCaseToUnderscope = camel_case_to_underscope



def underscope_to_camel_case(underscope_string: str, leading_upper_if_not_private: bool = False) -> str:
    result = ''
    i = 0
    if (i < len(underscope_string)):
        if (underscope_string[i] == '_'):
            i += 1
            s = underscope_string[i]
        elif (leading_upper_if_not_private):
            s = underscope_string[i].upper()
        else:
            s = underscope_string[i].lower()

        result += s
        i += 1

    while (i < len(underscope_string)):
        s = underscope_string[i]
        if (s == '_'):
            result += underscope_string[i + 1].upper()
            i += 1
        else:
            result += s.lower()
            
        i += 1

    return result
underscopeToCamelCase = underscope_to_camel_case
UnderscopeToCamelCase = underscope_to_camel_case



from distutils.core import setup
import tests

setup \
(
    name='camel-case-switcher',
    version='1.0',
    packages=['camel_case_switcher'],
    test_suite = 'tests',
    url='https://gitlab.com/Hares/camel-case-switcher',
    download_url='https://gitlab.com/Hares/camel-case-switcher/repository/master/archive.tar.gz',
    license='MIT',
    author='USSX Hares / Peter Zaitcev',
    author_email='ussx.hares@yandex.ru',
    description='Python tool for changing style in name of functions etc. from camelCase/CamelCase to the underscope_style.',
    keywords=['camel_case', 'strings', 'undescope_style'],
)
